%% TDE_K3_ETA0_KAPPA04_MEASSNRSWEEP is a numerical experiment script
% 
% This numerical experiment script uses the TDE_MAIN function to run 
% experiments with K=3 well-spaced pulses (ETA=0). The subsampling ratio in
% this experiment is set to KAPPA=0.4 and measurement noise is added.
%
% IMPORTANT: Before beginning a new numerical experiment, delete all the 
% temporary files under the TMP folder!
%
% Code implemented by: Karsten Fyhn
% Contact e-mail: kfn@es.aau.dk
%
% Copyright 2013 Karsten Fyhn
%
% Licensed under the Apache License, Version 2.0 (the "License");
% you may not use this file except in compliance with the License.
% You may obtain a copy of the License at
%
%   http://www.apache.org/licenses/LICENSE-2.0
%
% Unless required by applicable law or agreed to in writing, software
% distributed under the License is distribued on an "AS IS" BASIS,
% WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
% See the License for the specific language governing permissions and
% limitations under the License.
clear; clc;
addpath('../signal_generators','../recon_algorithms','../misc','../.');

% Set random seed
seed = int32(10^8*abs(now-double(int32(now))));
if seed~=0
    s = RandStream('mcg16807','Seed',seed);
    RandStream.setGlobalStream(s);
end

% Experiment variables
kappas = 0.4;
measSNRs = linspace(0,50,11);
sigSNRs = 1000;
noRuns = 1;
K = 3;
N = 500;
lambda = 10^0;
b_sep = 10^(-6);
eta = 0;

ii = 1;
methods{ii} = 'BOMP';           ii = ii+1;
methods{ii} = 'PaIBOMP';        ii = ii+1;
methods{ii} = 'TDE-MUSIC';      ii = ii+1;
methods{ii} = 'CCBP';           ii = ii+1;
methods{ii} = 'PaIBOMP+CCBP';   ii = ii+1;
methods{ii} = 'PoIBOMP';

fn = strcat(mfilename(),'_',int2str(seed));
tde_main(methods, N, K, lambda, kappas, measSNRs, sigSNRs, b_sep, eta, noRuns, fn);
