%% LAMBDA_ANALYSIS_TDE_KAPPA1_SNRLAMBDASWEEP is a lambda analysis script
% 
% This numerical experiment generates the data to plot lambda analysis 
% plots for KAPPA=1 and with varying SNR and LAMBDA values.
%
% Code implemented by: Karsten Fyhn
% Contact e-mail: kfn@es.aau.dk
%
% Copyright 2013 Karsten Fyhn
%
% Licensed under the Apache License, Version 2.0 (the "License");
% you may not use this file except in compliance with the License.
% You may obtain a copy of the License at
%
%   http://www.apache.org/licenses/LICENSE-2.0
%
% Unless required by applicable law or agreed to in writing, software
% distributed under the License is distribued on an "AS IS" BASIS,
% WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
% See the License for the specific language governing permissions and
% limitations under the License.
clear; clc;
addpath('../signal_generators','../recon_algorithms','../misc','../.');

% Set random seed
seed = int32(10^8*abs(now-double(int32(now))));
if seed~=0
    s = RandStream('mcg16807','Seed',seed);
    RandStream.setGlobalStream(s);
end

% Experiment variables
kappa = 1;
measSNRs = linspace(0,30,4);
sigSNR = 1000;
noRuns = 1;
K = 1;
N = 500;
lambdas = 10.^(-6:1:6); % Sparsity-to-fidelity ratio
b_sep = 0;
eta = 1;

methods{1} = 'CCBP';            

fn = strcat(mfilename(),'_',int2str(seed));
tde_main(methods, N, K, lambdas, kappa, measSNRs, sigSNR, b_sep, eta, noRuns, fn);