%% B_MSE_ERR finds the parameter estimate mean squared error
%
% [ BMSE ] = B_MSE_ERR(TRUE_BS, EST_BS)
%
% This function finds the mean squared error (MSE) of the parameter
% estimates, BS, using the Hungarian algorithm to match entries.
%
% Input variables:
%   TRUE_BS     The true parameter values.
%   EST_BS      The estimated parameter values.
%
% Output variables:
%   BMSE        The MSE for the estimates.
%
% Code implemented by: Karsten Fyhn
% Contact e-mail: kfn@es.aau.dk
%
% Copyright 2013 Karsten Fyhn
%
% Licensed under the Apache License, Version 2.0 (the "License");
% you may not use this file except in compliance with the License.
% You may obtain a copy of the License at
%
%   http://www.apache.org/licenses/LICENSE-2.0
%
% Unless required by applicable law or agreed to in writing, software
% distributed under the License is distribued on an "AS IS" BASIS,
% WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
% See the License for the specific language governing permissions and
% limitations under the License.
function [ bMSE ] = b_mse_err(true_bs, est_bs)
    N1 = length(true_bs);
    N2 = length(est_bs);
    if N1 == N2
        dM_bomp = abs(repmat(true_bs, 1, N1) - repmat(est_bs', N2, 1)).^2;
    elseif N1 > N2
        est_bs = padarray(est_bs, N1-N2, 0, 'post');
        dM_bomp = abs(repmat(true_bs, 1, N1) - repmat(est_bs', N1, 1)).^2;
    else
        true_bs = padarray(true_bs, N2-N1, 0, 'post');
        dM_bomp = abs(repmat(true_bs, 1, N2) - repmat(est_bs', N2, 1)).^2;
    end
    asgm_bomp = assignmentoptimal(dM_bomp);
    bMSE = mean((est_bs(asgm_bomp)-true_bs).^2);   
end

