%% MUSICAPPROX applies the MUSIC algorithm to a signal
%
% [ B ] = MUSICAPPROX(Y, K)
%
% This function finds estimate of the translation parameters B from an 
% input signal Y and the number of translation parameters K.
%
% Input variables:
%   Y   The input signal.
%   K   The number of translation-invariant signal components in Y.
%
% Output variables:
%   B   The estimated parameters.
%
% Code implemented by: Karsten Fyhn
% Contact e-mail: kfn@es.aau.dk
%
% Copyright 2013 Karsten Fyhn
%
% Licensed under the Apache License, Version 2.0 (the "License");
% you may not use this file except in compliance with the License.
% You may obtain a copy of the License at
%
%   http://www.apache.org/licenses/LICENSE-2.0
%
% Unless required by applicable law or agreed to in writing, software
% distributed under the License is distribued on an "AS IS" BASIS,
% WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
% See the License for the specific language governing permissions and
% limitations under the License.
function b = musicapprox(y, K)
N = length(y);
tmp = N*rootmusic(y, K, min(length(y)/4, 10*K)); 

% Recenter frequencies
idx = find(tmp < 0);
tmp(idx) = tmp(idx)+N;
b = tmp;
end