%% MERGE_SIMULATION merges different numerical experiment files into one
%
% [ NORUNS ] = MERGE_SIMULATION(FILENAME, PLOTFIG)
%
% This function takes as input a root FILENAME, which is used to find the 
% individual numerical experiments with that root FILENAME in the tmp 
% folder and merge these into one file. If PLOT=1, the output functions 
% results are plotted using the PLOT_LAMBDA_NUM_EXP function.
%
% Input variables:
%   FILENAME    The root filename to use for merging.
%   FOLDER      The directory where the files for merging are.
%   PLOTFIG     Whether to plot (PLOTFIG=1) or not (PLOTFIG=0) the merged 
%                   files' contents.
%
% Output variables:
%   NORUNS      The number of numerical experiments in the merged file.
%
% Code implemented by: Karsten Fyhn
% Contact e-mail: kfn@es.aau.dk
%
% Copyright 2013 Karsten Fyhn
%
% Licensed under the Apache License, Version 2.0 (the "License");
% you may not use this file except in compliance with the License.
% You may obtain a copy of the License at
%
%   http://www.apache.org/licenses/LICENSE-2.0
%
% Unless required by applicable law or agreed to in writing, software
% distributed under the License is distribued on an "AS IS" BASIS,
% WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
% See the License for the specific language governing permissions and
% limitations under the License.
function noRuns = merge_simulations(filename, folder, plotfig)
    files = what(folder);
    mat_files = files.mat;
    idxs = strfind(mat_files, filename);
    f_errors = []; bMSE_errors = []; comp_times = [];
    for ii=1:length(mat_files)
        if cell2mat(idxs(ii)) == 1;
            results = load(strcat(folder,char(mat_files(ii))));
            f_errors = cat(5, f_errors, results.f_errors);
            bMSE_errors = cat(5, bMSE_errors, results.bMSE_errors);
            comp_times = cat(5, comp_times, results.comp_times);
        end
    end
    noRuns = size(bMSE_errors,5);
    methods = results.methods; kappas = results.kappas; measSNRs = results.measSNRs; 
    sigSNRs = results.sigSNRs; K = results.K; lambdas = results.lambdas;
    save(filename, 'methods', 'f_errors', 'bMSE_errors', 'comp_times', 'lambdas', 'kappas', 'measSNRs', 'sigSNRs', 'K');    
    if plotfig
       plot_num_exp(filename, 0, 0);
    end
    display(noRuns);
end