%% CHIRP generates a chirp signal.
%
% [SIG] = CHIRP(T, F_0, DELTA_F, DURATION)
%
% CHIRP generates a linear chirp signal.
%
% Input variables:
%   T               The vector of time samples.
%   F_0             The carrier frequency.
%   DELTA_F         The sweep frequency.
%   DURATION        The duration of the chirp signal
%
% Output variables:
%   SIG             The sampled chirp signal.
% 
% Code implemented by: Karsten Fyhn
% Contact e-mail: kfn@es.aau.dk
%
% Copyright 2012 Karsten Fyhn
%
% Licensed under the Apache License, Version 2.0 (the "License");
% you may not use this file except in compliance with the License.
% You may obtain a copy of the License at
%
%   http://www.apache.org/licenses/LICENSE-2.0
%
% Unless required by applicable law or agreed to in writing, software
% distributed under the License is distribued on an "AS IS" BASIS,
% WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
% See the License for the specific language governing permissions and
% limitations under the License.
function sig = chirp(t, f_0, delta_f, T)
    sig = exp(1j*2*pi*((f_0+delta_f/(2*T)*(t-T/2)).*(t-T/2)));
    window = T/2 * (1 + cos(2*pi*(t-T/2)/T));
    window(t>T) = 0;
    window(t<0) = 0;
    sig = sig.*window;
    if sum(abs(sig).^2) ~= 0
        sig = sig/sqrt(sum(abs(sig).^2));
    end
end

