%% CHIRP_EXAMPLE is an example script that generates a chirp using chirp.m
% 
% Code implemented by: Karsten Fyhn
% Contact e-mail: kfn@es.aau.dk
%
% Copyright 2012 Karsten Fyhn
%
% Licensed under the Apache License, Version 2.0 (the "License");
% you may not use this file except in compliance with the License.
% You may obtain a copy of the License at
%
%   http://www.apache.org/licenses/LICENSE-2.0
%
% Unless required by applicable law or agreed to in writing, software
% distributed under the License is distribued on an "AS IS" BASIS,
% WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
% See the License for the specific language governing permissions and
% limitations under the License.
clear; clc; 
N = 100;
f_s = 50*10^6;
dt = 1/f_s;
t = (0:(N-1))*dt;
t_axis = t*10^6;
f = f_s/2 * linspace(-1,1,N);
f_axis = f./10^6;
f_0 = 10^6; delta_f = 40*f_0; T = 10^(-6);
g =@(tau) chirp(t-tau, f_0, delta_f, T);

tau = 0*10^(-6); % delay

chrp = exp(1j*2*pi*((f_0+delta_f/(2*T)*(t-T/2-tau)).*(t-T/2-tau)));
window = T/2 * (1 + cos(2*pi*(t-T/2-tau)/T));
window((t-tau)>T) = 0;
window((t-tau)<0) = 0;
sig = chrp.*window;
if sum(abs(sig).^2) ~= 0
    sig = sig/sqrt(sum(abs(sig).^2));
end

figure(1); clf;
subplot('311');
plot(t_axis, real(chrp), 'r-x'); hold on
plot(t_axis, imag(chrp), 'b-x');
subplot('312');
plot(t_axis, real(window), 'r-x'); hold on
plot(t_axis, imag(window), 'b-x');
subplot('313');
plot(t_axis, real(sig), 'r-x'); hold on
plot(t_axis, imag(sig), 'b-x');
xlabel('Microseconds');

figure(2); clf;
subplot('311');
CHRP = fftshift(fft(chrp)*dt);
plot(f_axis, real(CHRP), 'r-x'); hold on
plot(f_axis, imag(CHRP), 'b-x');
subplot('312');
WINDOW = fftshift(fft(window)*dt);
plot(f_axis, real(WINDOW), 'r-x'); hold on
plot(f_axis, imag(WINDOW), 'b-x');
subplot('313');
SIG = fftshift(fft(sig)*dt);
plot(f_axis, abs(SIG), 'r-x');
xlabel('MHz');

H = abs(SIG);
sum1=sum(H(f>-25*10^6 & f<25*10^6));
sum2 = sum(H);
display('Percent of the energy of signal between -25 and 25MHz:'); 
sum1/sum2


