%% GEN_AS generates complex amplitude coefficients within a desired range.
%
% [AS] = GEN_AS(MIN_A, MAX_A, K)
%
% Input variables:
%   MIN_A   The minimum value of a.
%   MAX_A   The maximum value of a.
%   K       The number of amplitudes to generate.
%
% Output variables:
%   AS      The generated amplitudes as a vector.
% 
% Code implemented by: Karsten Fyhn
% Contact e-mail: kfn@es.aau.dk
%
% Copyright 2013 Karsten Fyhn
%
% Licensed under the Apache License, Version 2.0 (the "License");
% you may not use this file except in compliance with the License.
% You may obtain a copy of the License at
%
%   http://www.apache.org/licenses/LICENSE-2.0
%
% Unless required by applicable law or agreed to in writing, software
% distributed under the License is distribued on an "AS IS" BASIS,
% WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
% See the License for the specific language governing permissions and
% limitations under the License.
function [ as ] = gen_as(min_a, max_a, K)
    as = zeros(K,1);
    for ii = 1:K
        r_a = max_a*(2*rand(1)-1);
        i_a = max_a*(2*rand(1)-1);
        while abs(r_a) < min_a || abs(i_a) < min_a
            r_a = max_a*(2*rand(1)-1);
            i_a = max_a*(2*rand(1)-1);
        end
        as(ii) = r_a + 1j*i_a;
    end
        
end

