%% SCS_SPARK numerically evalues the upper bound on the Spark of a SCS dictionary
% 
% Code implemented by: Karsten Fyhn
% Contact e-mail: kfn@es.aau.dk
%
% Copyright 2013 Karsten Fyhn
%
% Licensed under the Apache License, Version 2.0 (the "License");
% you may not use this file except in compliance with the License.
% You may obtain a copy of the License at
%
%   http://www.apache.org/licenses/LICENSE-2.0
%
% Unless required by applicable law or agreed to in writing, software
% distributed under the License is distribued on an "AS IS" BASIS,
% WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
% See the License for the specific language governing permissions and
% limitations under the License.
clear;
addpath('../signal_generators');

% Experiment parameters
N = 100;
c = 5;
Delta = 1/c;

% Function g
t = (0:N-1)';
g =@(omega) exp(1j*2*pi*omega*t/N)/sqrt(N);

% Dictionary
P = c*N;
D = zeros(N,P);
betas_D = (0:Delta:N-Delta);
for ii = 1:length(betas_D)
    D(:,ii) = g(betas_D(ii));
end
mu = abs(D'*D);

results = zeros(P,P);
zero_vector_N = zeros(N,1);
fprintf(1,'##############\n');
fprintf(1, 'Progress: %3d%%', 0);
for ii = 1:P
    cvx_begin
        cvx_quiet(1);
        variable x(P) complex
        minimize( norm( x, 1 ) )
        subject to
            D*x == zero_vector_N;
            x(ii) == 1;
    cvx_end
    results(:,ii) = x;
    fprintf(1, '\b\b\b\b%3d%%', round(100*ii/P));
end
fprintf(1,'\n');
spark_upperbound = min(sum(abs(results)>10^(-6), 1));
display(spark_upperbound);