%% TDE_SPARK numerically evalues the upper bound on the Spark of a TDE dictionary
% 
% Code implemented by: Karsten Fyhn
% Contact e-mail: kfn@es.aau.dk
%
% Copyright 2013 Karsten Fyhn
%
% Licensed under the Apache License, Version 2.0 (the "License");
% you may not use this file except in compliance with the License.
% You may obtain a copy of the License at
%
%   http://www.apache.org/licenses/LICENSE-2.0
%
% Unless required by applicable law or agreed to in writing, software
% distributed under the License is distribued on an "AS IS" BASIS,
% WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
% See the License for the specific language governing permissions and
% limitations under the License.
clear;
addpath('../signal_generators');

% Experiment parameters
N = 500;

% Function g
f_s = 50*10^6;
dt = 1/f_s;
Delta = dt;
t = (0:(N-1))'*dt;
f_0 = 10^6; delta_f = 40*f_0; T = 10^(-6);
g =@(tau) chirp(t-tau, f_0, delta_f, T);

% Dictionary
D = zeros(N);
Omega = (0:Delta:((N-1)*Delta));
D(:,1) = g(Omega(1));
for ii = 2:N
    D(:,ii) = circshift(D(:,ii-1),1);
end
mu = abs(D'*D);

results = zeros(N,N);
zero_vector = zeros(N,1);
fprintf(1,'##############\n');
fprintf(1, 'Progress: %3d%%', 0);
for ii = 1:N
    cvx_begin
        cvx_quiet(1);
        variable x(N) complex
        minimize( norm( x, 1 ) )
        subject to
            D*x == zero_vector;
            x(ii) == 1;
    cvx_end
    results(:,ii) = x;
    fprintf(1, '\b\b\b\b%3d%%', round(100*ii/N));
end
fprintf(1,'\n');
spark_upperbound = min(sum(results>10^(-6), 1));
display(spark_upperbound);